

if( TARGET ic4::core )
	set( IC4_SHOW_MESSAGE Off)
else()	# already configured
	set( IC4_SHOW_MESSAGE On)
endif()

include(${CMAKE_CURRENT_LIST_DIR}/ic4Targets.cmake)

if( WIN32 )

	set( IC4_RUNTIME_FILE_PATHS )	# Exported variable which will receive the paths to the runtime dlls needed for a ic4 windows program

	include( ${CMAKE_CURRENT_LIST_DIR}/runtime_file_list.cmake )		# Generated file exports ${IC4_RUNTIME_FILES_LIST} which contains the filenames of the runtime dlls

	foreach( file ${IC4_RUNTIME_FILES_LIST} )							# Generates a generator expression for each file to get a full absolute path to each runtime dll
		list( APPEND IC4_RUNTIME_FILE_PATHS "$<TARGET_FILE_DIR:ic4::core>/${file}" )	
	endforeach()

	function(ic4_copy_runtime_to_target target_name)
		add_custom_command(
			TARGET ${target_name} POST_BUILD
			COMMAND ${CMAKE_COMMAND} -E copy
				${IC4_RUNTIME_FILE_PATHS}
				$<TARGET_FILE_DIR:${target_name}>
		)
	endfunction()

else()

	function(ic4_copy_runtime_to_target target_name)	# For Unix this function does nothing

	endfunction()

endif()

if( ${IC4_SHOW_MESSAGE} )

	message(STATUS "The package ic4 provides CMake targets: ")
	message(STATUS "" )
	message(STATUS "    find_package( ic4 REQUIRED )" )
	message(STATUS "    target_link_libraries(main PRIVATE ic4::core)" )
	if( TARGET ic4::gui )
		message(STATUS "    target_link_libraries(main PRIVATE ic4::gui)" )
	endif()
	message(STATUS "" )
	message(STATUS "  (Win32) To copy the runtime DLLs next to your target output use:" )
	message(STATUS "" )
	message(STATUS "    ic4_copy_runtime_to_target(main)" )
	message(STATUS "" )
	message(STATUS "  (Win32) To install the runtime DLLs for your executable use:" )
	message(STATUS "" )
	message(STATUS "    install(FILES \${IC4_RUNTIME_FILES} TYPE BIN)" )
	message(STATUS "" )

endif()